@@ -8,14 +8,12 @@ typedef struct _gaainfo gaainfo;
 
 struct _gaainfo
 {
-#line 55 "shash.gaa"
+#line 52 "shash.gaa"
 	char **input;
-#line 54 "shash.gaa"
+#line 51 "shash.gaa"
 	int size;
-#line 45 "shash.gaa"
+#line 42 "shash.gaa"
 	char *keys;
-#line 40 "shash.gaa"
-	int nolock;
 #line 36 "shash.gaa"
 	char *algorithm;
 #line 33 "shash.gaa"
@@ -51,7 +49,7 @@ extern "C"
 
     int gaa(int argc, char *argv[], gaainfo *gaaval);
 
-    void gaa_help();
+    void gaa_help(void);
     
     int gaa_file(char *name, gaainfo *gaaval);
     
