@@ -1,6 +1,6 @@
 /*    SHASH, a program to compute secure hashes for files.
  *
- *    Copyright (C) 1998,1999 Nikos Mavroyanopoulos
+ *    Copyright (C) 1998,1999,2001,2002 Nikos Mavroyanopoulos
  *
  *    This program is free software; you can redistribute it and/or modify
  *    it under the terms of the GNU General Public License as published by
@@ -26,7 +26,6 @@
 #include <gaa.h>
 #include <errors.h>
 #include <extra.h>
-#include <locks.h>
 #include <random.h>
 #include <environ.h>
 #include <time.h>
@@ -39,7 +38,6 @@
 #define MAX_NAME 4096
 
 int quiet = 0;
-int nolock = FALSE;
 char msg[400];
 word32 salt[2];			/* 8 bytes */
 int set_salt = 0;
@@ -114,7 +112,6 @@ int main(int argc, char **argv)
 
 	quiet = info.quiet;
 	nosalt = info.nosalt;
-	nolock = info.nolock;
 	hmac = info.hmac;
 	double_check = info.double_check;
 	show_time = info.show_time;
@@ -398,10 +395,6 @@ void *sumfile(char *filename, hashid algorithm, char *password, int plen)
 			return NULL;
 		}
 
-		if (read_lock(fileno(file)) == -1) {
-			fclose(file);
-			return NULL;
-		}
 	} else {
 		file = stdin;
 
@@ -459,7 +452,6 @@ void *sumfile(char *filename, hashid algorithm, char *password, int plen)
 	end_time = time(0);
 #endif
 	
-	unlock(fileno(file));
 	fclose(file);
 
 	if (show_time!=0) {
@@ -560,15 +552,6 @@ int checkfile(char *filename, hashid algorithm, char *keyword, int plen,
 
 	}
 
-	if (filename != NULL) {
-		if (read_lock(fileno(file)) == -1) {
-			sprintf(msg, "%s: File is locked.\n", filename);
-			err_crit(msg);
-			return 0;
-		}
-	}
-
-
 	x = 1;
 
 	for (;;) {
@@ -711,8 +694,6 @@ int checkfile(char *filename, hashid algorithm, char *keyword, int plen,
 	free(buffer2);
 	free(hexbuffer);
 
-	if (filename != NULL)
-		unlock(fileno(file));
 	fclose(file);
 
 	tmp = mhash_get_hash_name(algorithm);
@@ -736,7 +717,7 @@ int checkfile(char *filename, hashid algorithm, char *keyword, int plen,
 
 void hash_license()
 {
-	fprintf(stdout, ("\nCopyright (C) 1999 Nikos Mavroyanopoulos\n"
+	fprintf(stdout, ("\nCopyright (C) 1999,2001,2002 Nikos Mavroyanopoulos\n"
 "This program is free software; you can redistribute it and/or modify \n"
 "it under the terms of the GNU General Public License as published by \n"
 "the Free Software Foundation; either version 2 of the License, or \n"
@@ -757,7 +738,7 @@ void hash_version()
 	fprintf(stderr, ("shash v.%s (%s-%s-%s)\n"), VERSION, T_CPU,
 		T_VENDOR, T_OS);
 	fprintf(stderr,
-		("Copyright (C) 1999 Nikos Mavroyanopoulos (nmav@hellug.gr)\n"));
+		("Copyright (C) 1999,2001,2002 Nikos Mavroyanopoulos (nmav@hellug.gr)\n"));
 
 } 
 
