@@ -4,8 +4,12 @@ void *sumfile(char *filename, hashid algorithm, char *password, int plen);
 
 int checkfile(char *filename, hashid algorithm, char *password, int plen, char* kmode);
 
-void *print2bin(void *x, int sizeofx);
-char *bin2print(void *x, int sizeofx);
 void *hash_key ( char *key, int keylen);
 void *Getpass(hashid algorithm, char *key, int* plen, void *pkey, char* kmode);
 int check_hex(char *given_chain, int len);
+
+int keygen_algorithm_is_ok(char* algo);
+static char *bin2hex(const unsigned char *old, const size_t oldlen, size_t * newlen);
+void hex2bin(void *src, void* dst,int sizeofsrc);
+void *pass2key(hashid algorithm, char *kmode, int *keylen, void *password, int plen);
+int find_keygen_algorithm(char *algo);
